powered by
Ranking genes by signal to noise ratio according to their expression data.
rank_by_s2n(expmat, label)
A vector of rank of each gene according to signal to noise ratio.
A matrix of gene expression data. Each row is a gene and each column is a sample.
An integer vector of encoded pheotypes. Its value is 0 and 1. Its length should match the column number of expression matrix.
expdat <- matrix(rnorm(500), nrow = 25, ncol = 20) label <- rep(c(0, 1), 10) ranklist <- rank_by_s2n(expdat, label)
Run the code above in your browser using DataLab